@@ -1,22 +1,25 @@
-var globals = require("./globals.js"),
-  fieldTags = globals.fieldTags,
-  fieldTagNames = globals.fieldTagNames,
-  arrayFields = globals.arrayFields,
-  fieldTypes = globals.fieldTypes,
-  fieldTypeNames = globals.fieldTypeNames,
-  geoKeys = globals.geoKeys,
-  geoKeyNames = globals.geoKeyNames,
-  GeoTIFFImage = require("./geotiffimage.js");
+"use strict";
 
+var globals = require("./globals.js");
+var GeoTIFFImage = require("./geotiffimage.js");
+var DataView64 = require("./dataview64.js");
+
+var fieldTypes = globals.fieldTypes,
+    fieldTagNames = globals.fieldTagNames,
+    arrayFields = globals.arrayFields,
+    geoKeyNames = globals.geoKeyNames;
 
 /**
  * The abstraction for a whole GeoTIFF file.
  * @constructor
  * @param {ArrayBuffer} rawData the raw data stream of the file as an ArrayBuffer.
+ * @param {Object} [options] further options.
+ * @param {Boolean} [options.cache=false] whether or not decoded tiles shall be cached.
  */
-
-var GeoTIFF = function(rawData) {
-  this.dataView = new DataView(rawData);
+function GeoTIFF(rawData, options) {
+  this.dataView = new DataView64(rawData);
+  options = options || {};
+  this.cache = options.cache || false;
 
   var BOM = this.dataView.getUint16(0, 0);
   if (BOM === 0x4949) {
@@ -29,17 +32,35 @@ var GeoTIFF = function(rawData) {
     throw new TypeError("Invalid byte order value.");
   }
 
-  if (this.dataView.getUint16(2, this.littleEndian) !== 42) {
+  var magicNumber = this.dataView.getUint16(2, this.littleEndian);
+  if (this.dataView.getUint16(2, this.littleEndian) === 42) {
+    this.bigTiff = false;
+  }
+  else if (magicNumber === 43) {
+    this.bigTiff = true;
+    var offsetBytesize = this.dataView.getUint16(4, this.littleEndian);
+    if (offsetBytesize !== 8) {
+      throw new Error("Unsupported offset byte-size.");
+    }
+  }
+  else {
     throw new TypeError("Invalid magic number.");
   }
 
   this.fileDirectories = this.parseFileDirectories(
-    this.dataView.getUint32(4, this.littleEndian)
+    this.getOffset((this.bigTiff) ? 8 : 4)
   );
-};
+}
 
 GeoTIFF.prototype = {
-  getFieldTypeLength: function (fieldType) {
+  getOffset: function(offset) {
+    if (this.bigTiff) {
+      return this.dataView.getUint64(offset, this.littleEndian);
+    }
+    return this.dataView.getUint32(offset, this.littleEndian);
+  },
+
+  getFieldTypeLength: function(fieldType) {
     switch (fieldType) {
       case fieldTypes.BYTE: case fieldTypes.ASCII: case fieldTypes.SBYTE: case fieldTypes.UNDEFINED:
         return 1;
@@ -48,6 +69,7 @@ GeoTIFF.prototype = {
       case fieldTypes.LONG: case fieldTypes.SLONG: case fieldTypes.FLOAT:
         return 4;
       case fieldTypes.RATIONAL: case fieldTypes.SRATIONAL: case fieldTypes.DOUBLE:
+      case fieldTypes.LONG8: case fieldTypes.SLONG8: case fieldTypes.IFD8:
         return 8;
       default:
         throw new RangeError("Invalid field type: " + fieldType);
@@ -79,6 +101,12 @@ GeoTIFF.prototype = {
       case fieldTypes.SLONG:
         values = new Int32Array(count); readMethod = this.dataView.getInt32;
         break;
+      case fieldTypes.LONG8: case fieldTypes.IFD8:
+        values = new Array(count); readMethod = this.dataView.getUint64;
+        break;
+      case fieldTypes.SLONG8:
+        values = new Array(count); readMethod = this.dataView.getInt64;
+        break;
       case fieldTypes.RATIONAL:
         values = new Uint32Array(count*2); readMethod = this.dataView.getUint32;
         break;
@@ -105,12 +133,12 @@ GeoTIFF.prototype = {
     }
     // RATIONAL or SRATIONAL
     else {
-      for (i=0; i < (count*2); i+=2) {
+      for (i=0; i < count; i+=2) {
         values[i] = readMethod.call(
           this.dataView, offset + (i*fieldTypeLength), this.littleEndian
         );
         values[i+1] = readMethod.call(
-          this.dataView, offset + ((i+1)*fieldTypeLength), this.littleEndian
+          this.dataView, offset + (i*fieldTypeLength + 4), this.littleEndian
         );
       }
     }
@@ -125,11 +153,11 @@ GeoTIFF.prototype = {
     var fieldValues;
     var fieldTypeLength = this.getFieldTypeLength(fieldType);
 
-    if (fieldTypeLength * typeCount <= 4) {
+    if (fieldTypeLength * typeCount <= (this.bigTiff ? 8 : 4)) {
       fieldValues = this.getValues(fieldType, typeCount, valueOffset);
     }
     else {
-      var actualOffset = this.dataView.getUint32(valueOffset, this.littleEndian);
+      var actualOffset = this.getOffset(valueOffset);
       fieldValues = this.getValues(fieldType, typeCount, actualOffset);
     }
 
@@ -179,23 +207,28 @@ GeoTIFF.prototype = {
     var fileDirectories = [];
 
     while (nextIFDByteOffset !== 0x00000000) {
-      var numDirEntries = this.dataView.getUint16(nextIFDByteOffset, this.littleEndian);
-      var fileDirectory = {};
+      var numDirEntries = this.bigTiff ?
+          this.dataView.getUint64(nextIFDByteOffset, this.littleEndian) :
+          this.dataView.getUint16(nextIFDByteOffset, this.littleEndian);
 
-      for (var i = byteOffset + 2, entryCount = 0; entryCount < numDirEntries; i += 12, ++entryCount) {
+      var fileDirectory = {};
+      var i = nextIFDByteOffset + (this.bigTiff ? 8 : 2);
+      for (var entryCount = 0; entryCount < numDirEntries; i += (this.bigTiff ? 20 : 12), ++entryCount) {
         var fieldTag = this.dataView.getUint16(i, this.littleEndian);
         var fieldType = this.dataView.getUint16(i + 2, this.littleEndian);
-        var typeCount = this.dataView.getUint32(i + 4, this.littleEndian);
+        var typeCount = this.bigTiff ?
+            this.dataView.getUint64(i + 4, this.littleEndian):
+            this.dataView.getUint32(i + 4, this.littleEndian);
 
         fileDirectory[fieldTagNames[fieldTag]] = this.getFieldValues(
-          fieldTag, fieldType, typeCount, i + 8
+          fieldTag, fieldType, typeCount, i + (this.bigTiff ? 12 : 8)
         );
       }
       fileDirectories.push([
         fileDirectory, this.parseGeoKeyDirectory(fileDirectory)
       ]);
 
-      nextIFDByteOffset = this.dataView.getUint32(i, this.littleEndian);
+      nextIFDByteOffset = this.getOffset(i);
     }
     return fileDirectories;
   },
@@ -212,12 +245,12 @@ GeoTIFF.prototype = {
     if (!fileDirectoryAndGeoKey) {
       throw new RangeError("Invalid image index");
     }
-    return new GeoTIFFImage(fileDirectoryAndGeoKey[0], fileDirectoryAndGeoKey[1], this.dataView, this.littleEndian);
+    return new GeoTIFFImage(fileDirectoryAndGeoKey[0], fileDirectoryAndGeoKey[1], this.dataView, this.littleEndian, this.cache);
   },
 
   /**
    * Returns the count of the internal subfiles.
-   * 
+   *
    * @returns {Number} the number of internal subfile images
    */
   getImageCount: function() {
