@@ -1,3 +1,5 @@
+"use strict";
+
 var fieldTagNames = {
   // TIFF Baseline
   0x013B: 'Artist',
@@ -147,7 +149,11 @@ var fieldTypeNames = {
   0x0009: 'SLONG',
   0x000A: 'SRATIONAL',
   0x000B: 'FLOAT',
-  0x000C: 'DOUBLE'
+  0x000C: 'DOUBLE',
+  // introduced by BigTIFF
+  0x0010: 'LONG8',
+  0x0011: 'SLONG8',
+  0x0012: 'IFD8'
 };
 
 var fieldTypes = {};
@@ -155,8 +161,21 @@ for (key in fieldTypeNames) {
   fieldTypes[fieldTypeNames[key]] = parseInt(key);
 }
 
+var photometricInterpretations = {
+  WhiteIsZero: 0,
+  BlackIsZero: 1,
+  RGB: 2,
+  Palette: 3,
+  TransparencyMask: 4,
+  CMYK: 5,
+  YCbCr: 6,
+
+  CIELab: 8,
+  ICCLab: 9
+};
+
 var geoKeyNames = {
-  1024: 'GTModelTypeGeoKey', 
+  1024: 'GTModelTypeGeoKey',
   1025: 'GTRasterTypeGeoKey',
   1026: 'GTCitationGeoKey',
   2048: 'GeographicTypeGeoKey',
@@ -210,9 +229,16 @@ for (key in geoKeyNames) {
   geoKeys[geoKeyNames[key]] = parseInt(key);
 }
 
-// TODO: same for node.js
 var parseXml;
-if (typeof window.DOMParser !== "undefined") {
+// node.js version
+if (typeof window === "undefined") {
+  parseXml = function(xmlStr) {
+    // requires xmldom module
+    var DOMParser = require('xmldom').DOMParser;
+    return ( new DOMParser() ).parseFromString(xmlStr, "text/xml");
+  };
+}
+else if (typeof window.DOMParser !== "undefined") {
   parseXml = function(xmlStr) {
     return ( new window.DOMParser() ).parseFromString(xmlStr, "text/xml");
   };
@@ -232,6 +258,7 @@ module.exports = {
   arrayFields: arrayFields,
   fieldTypes: fieldTypes,
   fieldTypeNames: fieldTypeNames,
+  photometricInterpretations: photometricInterpretations,
   geoKeys: geoKeys,
   geoKeyNames: geoKeyNames,
   parseXml: parseXml
